cmd

package
v0.0.0-...-d795554 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 9, 2020 License: GPL-3.0 Imports: 21 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AuthorFunc

func AuthorFunc() string

AuthorFunc returns the current username.

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

type Build

type Build struct {
	Type         string   `yaml:"type"` // trellis, origin(main.go). default trellis
	Path         string   `yaml:"path"`
	Static       bool     `yaml:"static"`
	Flags        string   `yaml:"flags"`
	Ldflags      string   `yaml:"ldflags"`
	ExtLDFlags   []string `yaml:"ext_ldflags"`
	DelBuildFile bool     `yaml:"delete_build_file"`
}

Build build configure

type BuildConfig

type BuildConfig struct {
	Project Project `json:"project" yaml:"project"`
	// contains filtered or unexported fields
}

BuildConfig build config

func (*BuildConfig) RemovePath

func (p *BuildConfig) RemovePath() error

RemovePath remove build path

type CheckConfig

type CheckConfig struct {
	Extensions []string
	Length     int
	Location   string

	Version string
}

CheckConfig check licences & change logs' config

type Go

type Go struct {
	CGo bool `yaml:"cgo"`
}

Go go

type Project

type Project struct {
	Name    string `yaml:"name"`
	Version string `yaml:"version"`

	Build Build `yaml:"build"`

	Go Go `yaml:"go"`

	Services map[string]Service `yaml:"services"`
}

Project project config info

type Service

type Service struct {
	URL string `yaml:"url"`
}

Service service info

Jump to